---
layout: blog
week: 134
published: 2017-11-25 14:11:28
---

Here's what happened in the [Reproducible Builds](https://reproducible-builds.org) effort between Sunday November 12 and Saturday November 18 2017:

Past and upcoming events
------------------------

We plan to hold [an assembly at 34C3](https://events.ccc.de/congress/2017/wiki/index.php/Assembly:Reproducible-Builds) - hope to see you there!

On November 17th Chris Lamb presented at the [Open Compliance Summit](http://events.linuxfoundation.org/events/open-compliance-summit/) in Yokohama, Japan on how reproducible builds can ensure the long-term sustainability of technology infrastructure.


GSoC and Outreachy updates
--------------------------

We are pleased to announce that [Juliana Oliveira R (jwnx) will be mentored by
Mattia Rizzolo](https://www.outreachy.org/alums/) on Reproducible Builds /
diffoscope in this round of [Outreachy](https://www.outreachy.org/')!


Reproducible work in other projects
-----------------------------------

* [Tails](https://tails.boum.org) announced that they were proud to present Tails 3.3 as one of the "[world's first reproducible ISO images](https://tails.boum.org/news/reproducible_Tails/)".

* [Support for SOURCE\_DATE\_EPOCH in the \pdftrailerid command](http://tug.org/pipermail/tex-live/2017-November/040794.html) of [TeX Live](https://www.tug.org/texlive/) was merged.

* Pierre Pronchery (`khorben`) [submitted a patch to build pkgsrc packages reproducibly](http://mail-index.netbsd.org/tech-pkg/2017/11/12/msg019018.html).

* The Google Container Tools team [announced the release of container-diff](https://opensource.googleblog.com/2017/11/container-diff-for-comparing-container-images.html), a new project to help uncover differences between container images.


Bootstrapping and Diverse Double Compilation
--------------------------------------------

Work on bootstrapping also made progress in
[MesCC](https://gitlab.com/janneke/mes) from Jan Nieuwenhuizen. MesCC now
compiles a less heavily patched TinyCC into a `mes-tcc` which passes 41/69
of mescc's C tests.


Qt tests and `__FILE__`
-----------------------

Our [patched
GCC](https://tests.reproducible-builds.org/debian/index_repositories.html) that
we use for testing Debian unstable has uncovered an interesting issue with
certain Qt [build-time test
suites](https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=876901). The issue is
that test suites using `QFINDTESTDATA` depend on `__FILE__` to expand to
something that may be reused after compilation as a real filesystem path when
starting from the same working directory as the original compilation.

However, this behaviour is not explicitly guaranteed by formal documentation
about `__FILE__`, and thus when it is rewritten to be build-path-independent (by
a combination of our patched dpkg and GCC), the Qt tests break because their
usage is no longer expanded to a real path as they expected.

Several very short patches were suggested to resolve this issue, including
a one-liner that allows our patched GCC to specifically rewrite `__FILE__` in
Qt test code to a real path which takes advantage of the ability to specify
multiple mappings using [BUILD_PATH_PREFIX_MAP](https://reproducible-builds.org/specs/build-path-prefix-map/).

Separately, [work is under way to address the other unrelated
concerns](https://lists.alioth.debian.org/pipermail/reproducible-builds/Week-of-Mon-20170814/009124.html)
raised about the patch by [GCC upstream back in August](https://gcc.gnu.org/ml/gcc-patches/2017-08/msg00232.html).


Packages reviewed and fixed, and bugs filed
-------------------------------------------


* Adrian Bunk:
    * [#881453](https://bugs.debian.org/881453) filed against [primesieve](https://tracker.debian.org/pkg/primesieve).
    * [#881804](https://bugs.debian.org/881804) filed against [ruby2.3](https://tracker.debian.org/pkg/ruby2.3).
    * [#881865](https://bugs.debian.org/881865) filed against [libctapimkt](https://tracker.debian.org/pkg/libctapimkt).
    * [#881915](https://bugs.debian.org/881915) filed against [libidn2](https://tracker.debian.org/pkg/libidn2).
    * [#882002](https://bugs.debian.org/882002) filed against [gpaste](https://tracker.debian.org/pkg/gpaste).

* Chris Lamb:
    * [#881474](https://bugs.debian.org/881474) filed against [phatch](https://tracker.debian.org/pkg/phatch) (ASLR randomness in pointer).
    * [#881788](https://bugs.debian.org/881788) filed against [opusfile](https://tracker.debian.org/pkg/opusfile) (buildpath).
    * [#881872](https://bugs.debian.org/881872) filed against [ardour](https://tracker.debian.org/pkg/ardour) (hash randomness).
    * [#881905](https://bugs.debian.org/881905) filed against [py3c](https://tracker.debian.org/pkg/py3c) (buildpath).
    * [#882112](https://bugs.debian.org/882112) filed against [bitz-server](https://tracker.debian.org/pkg/bitz-server) (buildpath).

* Christoph Biedl:
    * [#881627](https://bugs.debian.org/881627) filed against [ruby-http-parser.rb](https://tracker.debian.org/pkg/ruby-http-parser.rb).

* Danny Lee:
    * [#881664](https://bugs.debian.org/881664) filed against [chessx](https://tracker.debian.org/pkg/chessx) (cpu?, hostname?, QT/rcc).
    * [#881666](https://bugs.debian.org/881666) filed against [kmag](https://tracker.debian.org/pkg/kmag) (cpu?).

* Matthias Klose:
    * [#881793](https://bugs.debian.org/881793) filed against [daisy-player](https://tracker.debian.org/pkg/daisy-player).
    * [#881794](https://bugs.debian.org/881794) filed against [gmerlin](https://tracker.debian.org/pkg/gmerlin).
    * [#881797](https://bugs.debian.org/881797) filed against [xmms2](https://tracker.debian.org/pkg/xmms2).

* Bernhard M. Wiedemann:
    * [coccinelle](https://github.com/coccinelle/coccinelle/pull/121) (date)
    * [opa-ff](https://github.com/01org/opa-ff/pull/10) (date)
    * [gambas](http://gambaswiki.org/bugtracker/edit?object=BUG.1215) (merged, filesystem/`readdir` order)

Reviews of unreproducible packages
----------------------------------

35 package reviews have been added, 56 have been updated and 31 have been removed in this week,
adding to our knowledge about [identified issues](https://tests.reproducible-builds.org/debian/index_issues.html).

1 issue type has been updated:

- [random\_contents\_in\_dat\_files\_generated\_by\_chasen-dictutils\_makemat](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/c0b8c1ab) (`bwiedemann`)

tests.reproducible-builds.org
-----------------------------

- Ed Maste (FreeBSD support):
    - Give `ntpd` a moment to write its PID file.
    - Start with the correct time.

- kpcyrd (Archlinux support):
    - Pass `SOURCE_DATE_EPOCH` from `jenkins_node_wrapper.sh`.
    - Set `SOURCE_DATE_EPOCH`.
    - Use `$ROOTCMD` properly.
    - Set `pkgext` to .pkg.tar.xz.
    - Fix lost packages.
    - Correctly recognize `__END__`.
    - `pacman.conf` is owned by `root` after upgrade.
    - Add repos to `pacman.conf`.
    
- Holger Levsen:
    * Arch Linux:
         * Re-enable the builders.
         * Add a third builder job to use new resources.
    * FreeBSD:
         * Ignore `freebsd_master_git?????????.tar.xz` when looking for unreproducible artifacts.
         * Document that `munin-node` was finally configured (and how `denyhosts` was configured too).
         * Our test VM has been upgraded to 11.1.
         * Document that `poudriere` was installed, user `mattia` created and filesystem resized.
    * Debian: Update documentation to reflect that the database is now kept in PostgreSQL.
    * Redistribute 13 cores and 24GB RAM from `pb17` to `pb3` and `pb4` (used to build LEDE, Arch & coreboot) and the FreeBSD VM.

Weekly QA work
--------------

During our reproducibility testing, FTBFS bugs have been detected and reported by:

 - Adam Borowski (1)
 - Adrian Bunk (30)
 - Andreas Beckmann (2)
 - Christoph Biedl (1)
 - Helmut Grohne (2)
 - James Cowgill (1)
 - Matthias Klose (4)

reproducible-website development
--------------------------------

- Chris Lamb:
    - Update some broken links and references on the contribute" page ([1](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/e93813f), [2](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/18bf322), [3](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/65f0dd8))
    - [Add a missing ")"](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/d5febee) Thanks to `itd` for the patch!

Misc.
-----

This week's edition was written by Chris Lamb, Holger Levsen and Ximin Luo & reviewed by a bunch of Reproducible Builds folks on IRC & the mailing lists.
