---
layout: report
year: "2019"
month: "08"
title: "Reproducible Builds in August 2019"
draft: false
date: 2019-09-06 11:33:37
---

[![]({{ "/images/reports/2019-08/reproducible-builds.png#right" | relative_url }})](https://reproducible-builds.org/)

**Welcome to the August 2019 report from the [Reproducible Builds](https://reproducible-builds.org) project!**
{: .lead}

In these monthly reports we outline the most important things that have happened in the world of Reproducible Builds and we have been up to.

As a quick recap of our project, whilst anyone can inspect the source code of free software for malicious flaws, most software is distributed to end users or systems as precompiled binaries. The motivation behind the reproducible builds effort is to ensure zero changes have been introduced during these compilation processes. This is achieved by promising identical results are always generated from a given source thus allowing multiple third-parties to come to a consensus on whether a build was changed or even compromised.

In August's month's report, we cover:

* **Media coverage & events** — *Webmin, CCCamp, etc.*
* **Distribution work** — *The first fully-reproducible package sets, openSUSE update, etc*
* **Upstream news** — *libfaketime updates, gzip, ensuring good definitions, etc.*
* **Software development** — *More work on diffoscope, new variations in our testing framework, etc.*
* **Misc news** — *From our mailing list, etc.*
* **Getting in touch** — *How to contribute, etc*

If you are interested in contributing to our project, please visit our [*Contribute*]({{ "/contribute/" | relative_url }}) page on our website.

---

## Media coverage & events

[![]({{ "/images/reports/2019-08/webmin.png#right" | relative_url }})](http://www.webmin.com/)

A backdoor was found in [Webmin](http://www.webmin.com/) a popular web-based application used by sysadmins to remotely manage Unix-based systems. Whilst more details can be found on [upstream's dedicated exploit page](http://www.webmin.com/exploit.html), it appears that the build toolchain was compromised. Especially of note is that the exploit "did not show up in any Git diffs" and thus would not have been found via an audit of the source code. The backdoor would allow a remote attacker to execute arbitrary commands with superuser privileges on the machine running Webmin. Once a machine is compromised, an attacker could then use it to launch attacks on other systems managed through Webmin or indeed any other connected system. Techniques such as reproducible builds can help detect exactly these kinds of attacks that can lay dormant for years. ([LWN comments](https://lwn.net/Articles/796951/))

In a talk titled [*There and Back Again, Reproducibly!*](https://cfp.linuxdev-br.net/2019/talk/VH9CCY/) Holger Levsen and Vagrant Cascadian presented at the 2019 edition of the [Linux Developer Conference](https://linuxdev-br.net/) in São Paulo, Brazil on Reproducible Builds.

[LWN](https://lwn.net) posted and hosted an interesting summary and discussion on [*Hardening the `file` utility for Debian*](https://lwn.net/Articles/796108). In July, Chris Lamb had cross-posted his reply to the "[Re: file(1) now with seccomp support enabled](https://lists.reproducible-builds.org/pipermail/rb-general/2019-July/001612.html)" thread, [originally started on the `debian-devel`](https://lists.debian.org/debian-devel/2019/07/msg00391.html) mailing list. In this post, Chris refers to our `strip-nondeterminism` tool not being able to accommodate the additional security hardening in [`file(1)`](http://darwinsys.com/file/) and the changes made to the tool in order to fix this issue which was causing a huge number of regressions in [our testing framework](http://tests.reproducible-builds.org/).

[![]({{ "/images/reports/2019-08/cccamp.png#right" | relative_url }})](https://events.ccc.de/camp/2019/)

The [Chaos Communication Camp](https://en.wikipedia.org/wiki/Chaos_Communication_Camp) — an international, five-day open-air event for hackers that provides a relaxed atmosphere for free exchange of technical, social, and political ideas — [hosted its 2019 edition](https://events.ccc.de/camp/2019/) where there were many discussions and meet-ups at least partly related to Reproducible Builds. This including the titular [Reproducible Builds Meetup](https://events.ccc.de/camp/2019/wiki/Session:Reproducible_Builds_Meetup) session which was attended by around twenty-five people where half of them were new to the project as well as [a session dedicated to all Arch Linux related issues](https://events.ccc.de/camp/2019/wiki/Session:Arch_Linux_Meetup).

---

### Distribution work

[![]({{ "/images/reports/2019-08/debian.png#right" | relative_url }})](https://debian.org/)

In Debian, the first "package sets" — ie. defined subsets of the entire archive — have become 100% reproducible including as the so-called "essential" set for the [bullseye distribution on the `amd64`](https://tests.reproducible-builds.org/debian/bullseye/amd64/pkg_set_essential.html) and the [`armhf`](https://tests.reproducible-builds.org/debian/bullseye/armhf/pkg_set_essential.html) architectures. This is thanks to work by Chris Lamb on [`bash`](https://bugs.debian.org/935127), [`readline`](https://bugs.debian.org/935363) and other low-level libraries and tools. Perl still has issues on [`i386`](https://tests.reproducible-builds.org/debian/rb-pkg/bullseye/i386/diffoscope-results/perl.html) and [`arm64`](https://tests.reproducible-builds.org/debian/rb-pkg/bullseye/arm64/diffoscope-results/perl.html), however.

Dmitry Shachnev [filed a bug report](https://bugs.debian.org/934405) against the `debhelper` utility that speaks to issues around using the date from the `debian/changelog` file as the source for the [`SOURCE_DATE_EPOCH`](https://reproducible-builds.org/docs/source-date-epoch/) environment variable as this can lead to non-intuitive results when package is automatically rebuilt via so-called binary (NB. not ["source"](https://wiki.debian.org/NonMaintainerUpload)) NMUs. A related issue was [later filed against `qtbase5-dev`](https://bugs.debian.org/934511) by Helmut Grohne as this exact issue led to an issue with co-installability across architectures.

Lastly, 115 reviews of Debian packages were added, 45 were updated and 244 were removed this month, appreciably adding to [our knowledge about identified issues](https://tests.reproducible-builds.org/debian/index_issues.html). Many issue types were updated by Chris Lamb, including [`embeds_build_data_via_node_preamble`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/5d91c741), [`embeds_build_data_via_node_rollup`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/e6b686f3), [`captures_build_path_in_beam_cma_cmt_files`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/850df406), [`captures_varying_number_of_build_path_directory_components`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/c0c72250) (discussed later), [`timezone_specific_files_due_to_haskell_devscripts`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/a1a65bba), etc.

[![]({{ "/images/reports/2019-08/opensuse.png#right" | relative_url }})](https://www.opensuse.org/)

Bernhard M. Wiedemann posted his [monthly Reproducible Builds status update](https://lists.opensuse.org/opensuse-factory/2019-08/msg00186.html) for the [openSUSE](https://opensuse.org/) distribution. New issues were found from enabling [Link Time Optimization](https://gcc.gnu.org/wiki/LinkTimeOptimization) (LTO) in this distribution's [*Tumbleweed*](https://software.opensuse.org/distributions/tumbleweed) branch. This affected, for example, [`nvme-cli`](https://gcc.gnu.org/bugzilla/show_bug.cgi?id=91307) as well as [`perl-XML-Parser` and `pcc`](https://bugzilla.opensuse.org/show_bug.cgi?id=1146634) with packaging issues.

---

## Upstream news

* [`libfaketime`](https://github.com/wolfcw/libfaketime) is a tool to trick programs into believing that the current system time is actually one specified by the user. This month, Bernhard M. Wiedemann requested [the ability to track and intercept calls that change file timestamps](https://github.com/wolfcw/libfaketime/issues/183) which can help better debug or fix reproducibility issues in software.

* Chris Lamb requested that the ["molior" build tool](https://github.com/molior-dbs/molior) prefers to [use the term "repeatable build"](https://github.com/molior-dbs/molior/issues/3) in order to avoid confusion over the term "reproducible."

* The "[gzip](https://www.gzip.org/)" program is commonly used to compress artifacts such as the [the source code archives generated by Sourcehut](https://todo.sr.ht/~sircmpwn/git.sr.ht/232) hosting platform, but depending on the specific program used, the output may be different. Daniel Edgecumbe [has submitted patches](http://lists.busybox.net/pipermail/busybox/2019-September/087438.html) to the [BusyBox](https://busybox.net/) suite of tools to ensure the output of its version of `gzip` matches the output of [GNU gzip](https://www.gnu.org/software/gzip/) when using the same options regardless of the configuration of BusyBox. In the process, an [off-by-one error](https://en.wikipedia.org/wiki/Off-by-one_error) in the default settings was also fixed.

* There was more progress on ensuring that the [`gem` tool in rubygems respects](https://github.com/rubygems/rubygems/issues/2290#issuecomment-522206365) the [`SOURCE_DATE_EPOCH`](https://reproducible-builds.org/docs/source-date-epoch/) environment variable.

[![]({{ "/images/reports/2019-08/openwrt.png#right" | relative_url }})](https://openwrt.org/)

* A [request to include `.buildinfo` files](https://github.com/openwrt/openwrt/pull/2121) in the [OpenWRT](https://openwrt.org/) operating system that targets embedded devices such as routes, etc. was accepted and merged upstream.

---

## Software development

#### Upstream patches

The Reproducible Builds project detects, dissects and attempts to fix as many currently-unreproducible packages as possible. We endeavour to send all of our patches upstream where appropriate. In August we wrote a large number of such patches, including:

* Bernhard M. Wiedemann:
    * [`buildad`](https://github.com/containers/buildah/pull/1805) (date)
    * [`dracut`](https://github.com/dracutdevs/dracut/issues/617) (CPU influences build result)
    * [`fwupd`](https://bugzilla.opensuse.org/show_bug.cgi?id=1143905) (unreproducible [LTO](https://gcc.gnu.org/wiki/LinkTimeOptimization) data)
    * [`gnutls`](https://gitlab.com/gnutls/gnutls/merge_requests/1058) (date / copyright year)
    * [`katacontainers-image-initrd/osbuilder`](https://github.com/kata-containers/osbuilder/pull/340) (shell date; new variant with nanoseconds)
    * [`kernel-obs-build`](https://lists.opensuse.org/opensuse-kernel/2019-08/msg00001.html) (date from `/etc/shadow`)
    * [`kernel-vanilla`](https://lists.opensuse.org/opensuse-kernel/2019-08/msg00000.html) (drop number of CPUs)
    * [`libfaketime`](https://github.com/wolfcw/libfaketime/issues/183) (toolchain: fix various builds under [`libfaketime`](https://github.com/wolfcw/libfaketime))
    * [`nethack`](https://build.opensuse.org/request/show/722212) (date and [`tar(1)`](https://en.wikipedia.org/wiki/Tar_(computing)))
    * [`pcc`](https://bugzilla.opensuse.org/show_bug.cgi?id=1146634) (unreproducible when building with [LTO](https://gcc.gnu.org/wiki/LinkTimeOptimization))
    * [`python-ipyparallel`](https://github.com/ipython/ipyparallel/issues/380) (Fails to build with a single CPU / `-j1`)
    * [`python-pytest-httpserver`](https://github.com/csernazs/pytest-httpserver/pull/22) (renew SSL certs to fix FTBFS after September 2019)
    * [`python-python3-saml`](https://github.com/onelogin/python3-saml/pull/156) (Fails to build in 2020)
    * [`sblim-cmpi-base`](https://build.opensuse.org/request/show/726294) (Disable parallel [`make`](https://en.wikipedia.org/wiki/Make_(software)) due to broken build dependencies)
* Chris Lamb:
    * [#872728](https://bugs.debian.org/872728) filed against [`desktop-file-utils`](https://tracker.debian.org/pkg/desktop-file-utils) (closed)
    * [#933783](https://bugs.debian.org/933783) filed against [`virulencefinder`](https://tracker.debian.org/pkg/virulencefinder).
    * [#933790](https://bugs.debian.org/933790) filed against [`norsnet`](https://tracker.debian.org/pkg/norsnet).
    * [#933834](https://bugs.debian.org/933834) filed against [`haskell-devscripts`](https://tracker.debian.org/pkg/haskell-devscripts).
    * [#933838](https://bugs.debian.org/933838) filed against [`superlu-dist`](https://tracker.debian.org/pkg/superlu-dist).
    * [#934120](https://bugs.debian.org/934120) filed against [`python-bleach`](https://tracker.debian.org/pkg/python-bleach).
    * [#934697](https://bugs.debian.org/934697) filed against [`re2c`](https://tracker.debian.org/pkg/re2c) ([filed upstream](https://github.com/skvadrik/re2c/pull/258)).
    * [#934698](https://bugs.debian.org/934698) filed against [`libchamplain`](https://tracker.debian.org/pkg/libchamplain) ([filed upstream](https://gitlab.gnome.org/GNOME/libchamplain/merge_requests/9))
    * [#934699](https://bugs.debian.org/934699) filed against [`scons`](https://tracker.debian.org/pkg/scons).
    * [#934767](https://bugs.debian.org/934767) filed against [`ecbuild`](https://tracker.debian.org/pkg/ecbuild).
    * [#934918](https://bugs.debian.org/934918) filed against [`python-etcd3gw`](https://tracker.debian.org/pkg/python-etcd3gw).
    * [#934919](https://bugs.debian.org/934919) filed against [`omnidb`](https://tracker.debian.org/pkg/omnidb).
    * [#935127](https://bugs.debian.org/935127) filed against [`bash`](https://tracker.debian.org/pkg/bash).
    * [#935361](https://bugs.debian.org/935361) filed against [`node-autoprefixer`](https://tracker.debian.org/pkg/node-autoprefixer).
    * [#935362](https://bugs.debian.org/935362) filed against [`gdbm`](https://tracker.debian.org/pkg/gdbm).
    * [#935363](https://bugs.debian.org/935363) filed against [`readline`](https://tracker.debian.org/pkg/readline).
    * [#935790](https://bugs.debian.org/935790) filed against [`node-package-preamble`](https://tracker.debian.org/pkg/node-package-preamble).
    * [#935846](https://bugs.debian.org/935846) filed against [`musescore-snapshot`](https://tracker.debian.org/pkg/musescore-snapshot).
    * [#936452](https://bugs.debian.org/936452) filed against [`ust-fs-extra`](https://tracker.debian.org/pkg/rust-fs-extra).
    * [#936453](https://bugs.debian.org/936453) filed against [`litl`](https://tracker.debian.org/pkg/litl).
* Mathieu Parent:
    * [`php-pear`](https://github.com/pear/pear-core/pull/96) — Fixes over 150 packages with date issues.

#### diffoscope

[![]({{ "/images/reports/2019-08/diffoscope.svg#right" | relative_url }})](https://diffoscope.org)

[`diffoscope`](https://diffoscope.org) is our in-depth and content-aware diff utility that can locate and diagnose reproducibility issues. It is run countless times a day on [our testing infrastructure](https://tests.reproducible-builds.org/debian/reproducible.html) and is essential for identifying fixes and causes of non-deterministic behaviour.

This month, Chris Lamb made the following changes:

* Improvements:
    * Don't fallback to an unhelpful raw hexdump when, for example, `readelf(1)` reports an minor issue in a section in an ELF binary. For example, when the `.frames` section is of the `NOBITS` type its contents are apparently "unreliable" and thus `readelf(1)` returns 1. ([#58](https://salsa.debian.org/reproducible-builds/diffoscope/issues/58), [#931962](https://bugs.debian.org/931962))
    * Include either standard error or standard output (not just the latter) when an external command fails.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/4689755)]
* Bug fixes:
    * Skip calls to `unsquashfs` when we are neither root nor running under `fakeroot`. ([#63](https://salsa.debian.org/reproducible-builds/diffoscope/issues/63))
    * Ensure that all of our artificially-created [`subprocess.CalledProcessError`](https://docs.python.org/3/library/subprocess.html) instances have `output` instances that are `bytes` objects, not `str`.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/eb02809)]
    * Correct a reference to `parser.diff`; `diff` in this context is a Python function in the module.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/8eb9e39)]
    * Avoid a possible traceback caused by a `str`/`bytes` type confusion when handling the output of failing external commands.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/b803d43)]
* Testsuite improvements:

    * Test for `4.4` in the output of `squashfs -version`, even though the Debian package version is `1:4.3+git190823-1`.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/7cecd8a)]
    * Apply a patch from László Böszörményi to update the `squashfs` test output and additionally bump the required version for the test itself. ([#62](https://salsa.debian.org/reproducible-builds/diffoscope/issues/62) & [#935684](https://bugs.debian.org/935684))
    * Add the `wabt` Debian package to the test-dependencies so that we run the [WebAssembly](https://webassembly.org/) tests on our continuous integration platform, etc.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/84ad96d)]
* Improve debugging:
    * Add the containing module name to the (eg.) "`Using StaticLibFile for ...`" debugging messages.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/2f101b8)]
    * Strip off trailing "`original size modulo 2^32 671`" (etc.) from `gzip` compressed data as this is just a symptom of the contents itself changing that will be reflected elsewhere. ([#61](https://salsa.debian.org/reproducible-builds/diffoscope/issues/61))
    * Avoid a lack of space between "`... with return code 1`" and "`Standard output`".&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/ffa22f8)]
    * Improve debugging output when instantantiating our `Comparator` object types.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/1647da8)]
    * Add a literal "eg." to the comment on stripping "`original size modulo...`" text to emphasise that the actual numbers are not fixed.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/18e3526)]
* Internal code improvements:
    * No need to parse the section group from the class name; we can pass it via `type` built-in `kwargs` argument.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/5261096)]
    * Add support to `Difference.from_command_exc` and friends to ignore specific returncodes from the called program and treat them as "no" difference.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/d3c7ac8)]
    * Simplify parsing of optional `command_args` argument to `Difference.from_command_exc`.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/cc9a730)]
    * Set `long_description_content_type` to `text/x-rst` to appease the [PyPI.org](https://pypi.org/) linter.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/7583af2)]
    * Reposition a comment regarding an exception within the indented block to match Python code convention.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope.git/commit/ec86443)]

In addition, Mattia Rizzolo made the following changes:

* Now that we install wabt, expect its tools to be available.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f2e72a8)]
* Bump the Debian backport check.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/9591cfb)]

Lastly, Vagrant Cascadian updated diffoscope to versions [120](https://git.savannah.gnu.org/cgit/guix.git/commit/?id=c91364d36cf6c8fc4c696d151eb9fca7832cf898), [121](https://git.savannah.gnu.org/cgit/guix.git/commit/?id=8c1379ba404b4db2f0afcf431a4ff720b72a7a19) and [122](https://git.savannah.gnu.org/cgit/guix.git/commit/?id=b126f41b301a5ac13835bf20026ae6d1d5ae2bee) in the [GNU Guix](https://guix.gnu.org/) distribution.

#### strip-nondeterminism

[strip-nondeterminism](https://tracker.debian.org/pkg/strip-nondeterminism) is our tool to remove specific non-deterministic results from a completed build. This month, Chris Lamb made the following changes.

* Add support for enabling and disabling specific normalizers via the command line. ([#10](https://salsa.debian.org/reproducible-builds/strip-nondeterminism/issues/10))
* Drop accidentally-committed warning emitted on every fixture-based test.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/strip-nondeterminism.git/commit/e1def58)]
* Reintroduce the `.ar` normalizer [[...](https://salsa.debian.org/reproducible-builds/strip-nondeterminism.git/commit/bb13f8b)] but disable it by default so that it can be enabled with `--normalizers=+ar` or similar. ([#3](https://salsa.debian.org/reproducible-builds/strip-nondeterminism#3))
* In verbose mode, print the normalizers that `strip-nondeterminism` will apply.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/strip-nondeterminism.git/commit/2637e1c)]

In addition, there was some movement on an issue in the [`Archive::Zip` Perl module](https://metacpan.org/pod/Archive::Zip) that `strip-nondeterminism` uses regarding the lack of support for [`bzip` compression](https://en.wikipedia.org/wiki/Bzip2) that [was originally filed in 2016](https://github.com/redhotpenguin/perl-Archive-Zip/issues/26) by [Andrew Ayer](https://www.agwa.name/).

#### Test framework

[![]({{ "/images/reports/2019-08/testframework.png#right" | relative_url }})](https://tests.reproducible-builds.org/)

We operate a comprehensive [Jenkins](https://jenkins.io/)-based testing framework that powers [tests.reproducible-builds.org](https://tests.reproducible-builds.org).

This month Vagrant Cascadian [suggested and subsequently implemented](https://salsa.debian.org/qa/jenkins.debian.net/commit/94469490) that we additionally test a varying build directory of different string lengths (eg. `/path/to/123` vs `/path/to/123456` but we also vary the number of directory *components* within this, eg. `/path/to/dir` vs. `/path/to/parent/subdir`. Curiously, whilst it was *a priori* believed that was rather unlikely to yield differences, Chris Lamb [has managed to identify approximately twenty packages](https://tests.reproducible-builds.org/debian/issues/unstable/captures_varying_number_of_build_path_directory_components_issue.html) that are affected by this issue.

[![]({{ "/images/reports/2019-08/coreboot.png#right" | relative_url }})](https://www.coreboot.org/)

It was also noticed that [our testing of the Coreboot free software firmware](https://tests.reproducible-builds.org/coreboot/coreboot.html) fails to build the toolchain since we switched to building on the Debian `buster` distribution. The [last successful build was on August 7th](https://jenkins.debian.net/job/reproducible_coreboot/356 was t) but all newer builds have failed.

In addition, the following code changes were performed in the last month:

* Chris Lamb: Ensure that the size the log for the second build in HTML pages was also correctly formatted (eg. "`12KB`" vs "`12345`").&nbsp;[[...](https://salsa.debian.org/reproducible-builds/jenkins.debian.net.git/commit/080d7ba3)]

* Holger Levsen:

    * Many changes related to updating our build nodes to the `buster` distribution for Debian.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/a97c97ec)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/6fb3ee7b)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/1fad75e4)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/7fef98af)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/da55be7a)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/28941bc2)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/309a1d66)]
    * Attempt to automatically fixup spurious build failures.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/82bee189)]
    * Update the maintainer address for [the Debian team tasked with maintaining](https://wiki.debian.org/Teams/pkg-mate) the [MATE desktop](https://mate-desktop.org/).&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/e6f7c6d4)]
    * Try not to build all the release tags of tools such as [diffoscope](https://diffoscope.org), etc..&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/974b699e)]
    * Use a newer kernel to support building the latest [Arch Linux](https://www.archlinux.org/) packages.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/7e575590)]
    * Re-add checks for "zombie" and log file size sanity checks.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/f17552ad)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/30049d46)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/9fbf8d2c)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/42d7c71a)]
    * Vary the choice of kernel on the `amd64` again by using the kernel from [Debian "backports"](https://backports.debian.org/).&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/b2870778)]
    * Drop some ancient Debian `jessie`-related configuration.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/96cbb81e)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/7e37c5a4)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/87840dae)]

* Mathieu Parent: Update the contact details for the [Debian PHP Group](https://wiki.debian.org/Teams/DebianPHPGroup).&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/03510cdf)]

* Mattia Rizzolo:
    * Update our [Postfix](http://www.postfix.org/) email server configuration.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/61ceaf5d)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/8780a849)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/3b964081)]
    * Use the `safe_load` function of [PyYAML](https://pyyaml.org/wiki/PyYAMLDocumentation) when parsing [YAML-formatted](https://en.wikipedia.org/wiki/YAML) files.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/fa720775)]

The usual node maintenance was performed by Holger Levsen&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/961d70a6)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/25f295b7)] and Vagrant Cascadian&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/30f567ff)].

---

## Misc news

[![]({{ "/images/reports/2019-08/website.png#right" | relative_url }})](https://reproducible-builds.org/)

There was a yet more effort put into our [our website](https://reproducible-builds.org/) this month, including misc copyediting by Chris Lamb&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/a911e9d)], Mathieu Parent referencing his fix for `php-pear`&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/e47ade1)] and Vagrant Cascadian updating a link to his homepage.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/7f8bc7e)].

On [our mailing list](https://lists.reproducible-builds.org/pipermail/rb-general/) this month Santiago Torres Arias started a [*Setting up a MS-hosted rebuilder with in-toto metadata*](https://lists.reproducible-builds.org/pipermail/rb-general/2019-August/001640.html) thread regarding Microsoft's interest in setting up a rebuilder for Debian packages touching on issues of transparency logs and the integration of [in-toto](https://in-toto.io/) by the [Secure Systems Lab](https://ssl.engineering.nyu.edu/) at [New York University](https://engineering.nyu.edu/). In addition, [Lars Wirzenius](https://liw.fi/) continued conversation regarding [various questions about reproducible builds](https://lists.reproducible-builds.org/pipermail/rb-general/2019-August/001634.html) and their bearing on building a distributed continuous integration system.

Lastly, in a thread titled [*Reproducible Builds technical introduction tutorial*](https://lists.reproducible-builds.org/pipermail/rb-general/2019-August/001639.html) Jathan asked whether anyone had some "easy" Reproducible Builds tutorials in slides, video or written document format.

---

## Getting in touch

If you are interested in contributing the Reproducible Builds project, please visit our [*Contribute*](https://reproducible-builds.org/contribute/) page on our website. However, you can get in touch with us via:

 * IRC: `#reproducible-builds` on `irc.oftc.net`.

 * Twitter: [@ReproBuilds](https://twitter.com/ReproBuilds)

 * Mailing list: [`rb-general@lists.reproducible-builds.org`](https://lists.reproducible-builds.org/listinfo/rb-general)

<br>

---

This month's report was written by Bernhard M. Wiedemann, Chris Lamb, Eli Schwartz, Holger Levsen, Jelle van der Waa, Mathieu Parent and Vagrant Cascadian. It was subsequently reviewed by a bunch of Reproducible Builds folks on IRC and the mailing list.
